# Channel statistic

Apply a function to subsets of a data set, and add it as a statistic to the experiment.

First, the module groups the data by the unique values of the variables in By, then applies Function to the Channel in each group.

Name

  The operation name. Becomes the first part of the new statistic’s name.

Channel

  The channel to apply the function to.

Function

  The function to compute on each group.

Subset

  Only apply the function to a subset of the data. Useful if the function is very slow.